from setuptools import setup
from os import path
import re


def packagefile(*relpath):
    return path.join(path.dirname(__file__), *relpath)


def read(*relpath):
    with open(packagefile(*relpath)) as f:
        return f.read()


def get_version(*relpath):
    match = re.search(
        r'''^__version__ = ['"]([^'"]*)['"]''',
        read(*relpath),
        re.M
    )
    if not match:
        raise RuntimeError('Unable to find version string.')
    return match.group(1)


setup(
    name='django-password-validation-backport',
    version=get_version('django_password_validation', '__init__.py'),
    description='Ported password validation code from Django 1.9.',
    long_description=read('README.rst'),
    url='https://github.com/luismsgomes/django-password-validation-backport',
    author='Luis Gomes',
    author_email='luismsgomes@gmail.com',
    license='MIT',
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 2.7',
    ],
    keywords='backport',
    install_requires=[
    ],
    package_dir={'': '.'},
    packages=['django_password_validation'],
    package_data={
        'django_password_validation': ['*.gz'],
    },
    include_package_data=True,
)



import importlib
import logging

from django.core.exceptions import MiddlewareNotUsed
from .validators import validate_password, password_changed


LOG = logging.getLogger('django_password_validation')


def inject_password_validation_into_django_password_form():
    from django.contrib.auth.forms import SetPasswordForm
    __real_clean_password2 = SetPasswordForm.clean_new_password2

    def clean_new_password2(self):
        password2 = self.cleaned_data.get('new_password2')
        validate_password(password2, self.user)
        return __real_clean_password2(self)

    SetPasswordForm.clean_new_password2 = clean_new_password2


def inject_password_validation_into_django_user_model():
    from django.contrib.auth.models import User
    __real_save = User.save

    def save(self, *args, **kwargs):
        LOG.info("User.save() => django_password_validation.password_change()")
        __real_save(self, *args, **kwargs)
        if self.password is not None:
            password_changed(self.password, self)

    User.save = save


class DjangoPasswordValidationMiddleware:
    def __init__(self):
        inject_password_validation_into_django_password_form()
        inject_password_validation_into_django_user_model()
        raise MiddlewareNotUsed



# code in django_password_validation_backport.validators was backported from
# django.contrib.auth.password_validation (Django 1.9)
__version__ = "0.1.3"

from .validators import \
    get_default_password_validators, \
    get_password_validators, \
    validate_password, \
    password_changed, \
    password_validators_help_texts, \
    password_validators_help_text_html, \
    MinimumLengthValidator, \
    UserAttributeSimilarityValidator, \
    CommonPasswordValidator, \
    NumericPasswordValidator

from .middleware import \
    DjangoPasswordValidationMiddleware